@@ -92,7 +92,8 @@ class Run:
         assert_that(artifact).is_not_none()
         return artifact.upload()
 
-    def get_artifact(self, name: str, type: str, tag: str="", team_name: str="", exp_name: str="") -> Tuple(int, ArtifactRecord):
+    def get_artifact(self, name: str, type: str, tag: str="", team_name: str="", exp_name: str="") -> Tuple[
+        int, ArtifactRecord]:
         assert_that(name).is_not_none()
         assert_that(type).is_not_none()
 
