@@ -1,8 +1,11 @@
 import re
-from typing import Dict, Callable
+from typing import Dict, Callable, Tuple
 from urllib.parse import urljoin
 
 import optuna
+import ast
+from assertpy import assert_that
+
 from optuna.exceptions import DuplicatedStudyError
 
 import deepdriver
@@ -116,14 +119,70 @@ def create_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hp
 @util.login_required
 def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_config: Dict = None,
             func: Callable = None, count: int = 10, artifact: Dict = None, job_count: int = 0) -> bool:
+    # assert_that(func).is_not_none()
+
     result1, hpoConfig = get_hpo(exp_name=exp_name, team_name=team_name)
     result2, study = load_hpo(exp_name=exp_name, team_name=team_name)
+
+    if artifact:
+        if "dataset" in artifact:
+            result, dataset_path = prepare_dataset(artifact["dataset"])
+            if result:
+                hpoConfig['dataset_path'] = dataset_path
+        if "code" in artifact:
+            result, code_path, func = prepare_code(artifact["code"])
+            if result:
+                hpoConfig['code_path'] = code_path
+
     result3 = run_optimize(exp_name=exp_name, team_name=team_name, func=func, config=hpoConfig, count=count,
                            study=study)
 
     return True
 
 
+@util.login_required
+def prepare_dataset(dataset: dict = None) -> Tuple[bool, str]:
+    assert_that(dataset).is_not_none()
+
+    arti = deepdriver.get_artifact(**dataset)
+    if arti.entry_list == []:
+        logger.error(f"artifat(name={dataset['name']}, type={dataset['type']}) have no entries")
+        return False, None
+    else:
+        path = arti.download()
+        return True, path
+
+
+@util.login_required
+def prepare_code(code: dict = None) -> Tuple[bool, str, Callable]:
+    assert_that(code).is_not_none()
+
+    arti = deepdriver.get_artifact(name=code['name'], type=code['type'])
+    if arti.entry_list == []:
+        return False, None, None
+    else:
+        path = arti.download()
+        # finding code file in entry_list
+        file_entry_list = next((entry.local_path for entry in arti.entry_list if entry.path.endswith(code['file'])),
+                               None)
+        if not file_entry_list:
+            raise Exception(f'cannot find file({code["file"]}) in artifcat')
+
+        # dynamically function load from file
+        with open(file_entry_list, "r") as file:
+            file_content = file.read()
+        node = ast.parse(file_content)
+
+        looking_for_body = next((body for body in node.body if body.name == code['fun']), None)
+        if not looking_for_body:
+            raise Exception(f'cannot find function({code["func"]}) in file_entry_list')
+        func_name = looking_for_body.name
+        func_source = ast.get_source_segment(file_content, looking_for_body)
+        exec(func_source)
+
+        return True, path, eval(func_name)
+
+
 @util.login_required
 def get_hpo(exp_name: str = "", team_name: str = "") -> (bool, Dict):
     team_name_ = team_name or get_experiment().team_name
@@ -153,11 +212,16 @@ def run_optimize(exp_name: str = "", team_name: str = "", func: Callable = None,
         deepdriver.init(exp_name=exp_name)
         get_config(trial, config)
         y = func()
-        deepdriver.log( {"result_score" : y})
+        deepdriver.log({"result_score": y})
         deepdriver.finish()
         return y
 
     def get_config(trial, config):
+        # config 의 dataset_path, code_path를 config에 저장
+        if ("dataset_path" in config) and ("code_path" in config):
+            deepdriver.config.dataset_path = config['dataset_path']
+            deepdriver.config.code_path = config['code_path']
+
         # config 의 parameters 내용을 조건에  따라 하기와 같은 코드로 변환
         for item_dict in config['parameters']:
             key: str = item_dict['key']
